Function term_basics_linux::set_colour [−][src]
pub fn set_colour(col: UC, fgbg: XG)Expand description
Sets the colour of the text printed after this call.
It will print linux colour escape characters to std out.
It will set the state, so you can use restore_colour to get it back.
Examples
use term_basics_linux as tbl;
for i in tbl::UC::iterator(){
tbl::set_colour(i.clone(), tbl::XG::FG);
println!("haha yes");
}use term_basics_linux as tbl;
for i in tbl::UC::iterator(){
tbl::set_colour(i.clone(), tbl::XG::BG);
println!("haha yes");
}